@@ -58,7 +58,7 @@
 #' @export
 getSmoothed <- function(inla_mod, nsim = 1000, weight.strata = NULL, weight.frame = NULL, verbose = FALSE, mc = 0, include_time_unstruct = FALSE, CI = 0.95, draws = NULL, save.draws = FALSE, include_subnational = TRUE, ...){
 
-      years <- region <- NA
+      years <- region <- age.diff <- NA
       lowerCI <- (1 - CI) / 2
       upperCI <- 1 - lowerCI
       save.draws.est <- save.draws
@@ -220,7 +220,7 @@ getSmoothed <- function(inla_mod, nsim = 1000, weight.strata = NULL, weight.fram
         if(!"region.struct:1" %in% fields) inla_mod$fit$.args$data$region.struct = 1
 
         rep.time <- length(unique(inla_mod$age.rw.group)) > 0
-        cols <- c("time.struct", "time.unstruct", "region.struct", "time.area", "strata", "age", "age.idx")
+        cols <- c("time.struct", "time.unstruct", "region.struct", "time.area", "strata", "age", "age.idx", "age.intercept", "age.diff")
         if(rep.time){
           cols <- c(cols, "age.rep.idx")
         } 
@@ -244,10 +244,29 @@ getSmoothed <- function(inla_mod, nsim = 1000, weight.strata = NULL, weight.fram
           if(sum(AA$strata != "") == 0) AA$strata <- "strata_all"
         }
         AA <- merge(AA, unique(A[, c("time.struct", "time.unstruct", "region.struct",  "time.area")]), by = "time.area")
-       if(rep.time){ 
-          AA <- merge(AA, unique(A[, c("age", "age.idx", "age.rep.idx")]), by = "age")
+        if("strata" %in% colnames(A)){
+          if(rep.time){ 
+            tmp <- unique(A[, c("strata", "age", "age.idx", "age.rep.idx", "age.intercept", "age.diff")])
+          }else{            
+            tmp <- unique(A[, c("strata", "age", "age.idx", "age.intercept", "age.diff")])
+          }        
         }else{
-          AA <- merge(AA, unique(A[, c("age", "age.idx")]), by = "age")
+          if(rep.time){ 
+            tmp <- unique(A[, c("age", "age.idx", "age.rep.idx", "age.intercept", "age.diff")])
+          }else{            
+            tmp <- unique(A[, c("age", "age.idx", "age.intercept", "age.diff")])
+          }    
+        }
+        # check the filler data contains any NA, which will make the merge call go wrong.
+        if(sum(!is.na(tmp$age.diff)) > 0){
+          tmp <- subset(tmp, !is.na(age.diff))
+        }else{
+          tmp <- tmp[, colnames(tmp) != "age.diff"]
+        }
+        if("strata" %in% colnames(tmp)){
+          AA <- merge(AA, tmp, by = c("age", "strata"))
+        }else{
+          AA <- merge(AA, tmp, by = c("age"))
         }
 
         if(!is.null(inla_mod$covariate.names)){
@@ -264,20 +283,31 @@ getSmoothed <- function(inla_mod, nsim = 1000, weight.strata = NULL, weight.fram
         if(!inla_mod$is.temporal){
           AA$time.struct <- AA$time.unstruct <- 1
         }        
-        AA$age <- paste0("age", AA$age, ":1")
+        AA$age.intercept <- paste0("age.intercept", AA$age.intercept, ":1")
+        AA$age.diff <- paste0("age.diff", AA$age.diff, ":1")
 
-        # When there's only one age group, smoothCluster uses the generic intercept
-        if(length(unique(AA$age)) == 1) AA$age <- "(Intercept):1"
+        # # When there's only one age group, smoothCluster uses the generic intercept
+        # # if(length(unique(AA$age.intercept)) == 1) AA$age.intercept <- "(Intercept):1"
+        
+        # Checking age intercept is tricky, directly check if intercept is in the posterior draws...
+        if("(Intercept):1" %in% fields){
+          AA$intercept <- "(Intercept):1"
+        }else{
+          AA$intercept <- NA
+        }
 
         #  AA.loc is the same  format as AA, but with location index
         AA.loc <- AA
-        AA.loc$age  <- match(AA.loc$age, fields)
+        AA.loc$age.intercept  <- match(AA.loc$age.intercept, fields)
+        AA.loc$age.diff  <- match(AA.loc$age.diff, fields)
+        AA.loc$age <- NA
         # For constant case, base strata will end up being NA here, which is fine.
         if(!is.dynamic) AA.loc$strata <- paste0("strata", AA.loc$strata, ":1")
         AA.loc$strata  <- match(AA.loc$strata, fields)
         if(!is.null(inla_mod$covariate.names)){
             AA.loc[, inla_mod$covariate.names] <- NA
         }
+        AA.loc$intercept <- match(AA.loc$intercept, fields)
 
         AA.loc$time.area  <- match(paste0("time.area:", AA.loc$time.area), fields)
         # Update time.area as the row index of the correct samples
@@ -714,6 +744,9 @@ getSmoothed <- function(inla_mod, nsim = 1000, weight.strata = NULL, weight.fram
 
         }
       }
+
+      ## TODO: In the future, extract posterior draws with inla.posterior.sample and fit1$lincombs.info and fit1$fit$.args$lincomb 
+
       results$is.yearly <- !(results$Year %in% year_label)
       results$years.num <- suppressWarnings(as.numeric(as.character(results$Year)))
       #  ## deal with 1 year case
